@@ -29,7 +29,7 @@ class AsyncSessionTestCase(unittest.TestCase):
             + list(dict.values(self.sessions))
 
     def run_sync(self, f, *args, **kwargs):
-        return asyncio.run(f(*args, **kwargs))
+        return self.loop.run_until_complete(f(*args, **kwargs))
 
     def setUp(self):
         try:
